@@ -1,8 +1,16 @@
 #!/usr/bin/env perl
 
+use 5.018;
+
+use strict;
+use warnings;
+
 use Venus::Data;
 
-# access content in the DATA token
+#
+# Access content in the DATA token
+#
+
 Venus::Data->new($0)->text->say('search', {list => undef, name => 'greet'});
 
 __DATA__
