@@ -7,7 +7,7 @@ use warnings;
 
 # VERSION
 
-our $VERSION = '3.40';
+our $VERSION = '3.55';
 
 # AUTHORITY
 
@@ -27,6 +27,8 @@ sub import {
     array => 1,
     arrayref => 1,
     assert => 1,
+    async => 1,
+    await => 1,
     bool => 1,
     box => 1,
     call => 1,
@@ -163,6 +165,22 @@ sub assert ($$) {
   return $assert->validate($data);
 }
 
+sub async ($) {
+  my ($code) = @_;
+
+  require Venus::Process;
+
+  return Venus::Process->new->async($code);
+}
+
+sub await ($;$) {
+  my ($process, $timeout) = @_;
+
+  require Venus::Process;
+
+  return $process->await($timeout);
+}
+
 sub bool (;$) {
   my ($data) = @_;
 
@@ -514,9 +532,26 @@ sub load ($) {
 sub log (@) {
   my (@args) = @_;
 
+  state $codes = {
+    debug => 'debug',
+    error => 'error',
+    fatal => 'fatal',
+    info => 'info',
+    trace => 'trace',
+    warn => 'warn',
+  };
+
+  unshift @args, 'debug' if @args && !$codes->{$args[0]};
+
   require Venus::Log;
 
-  return Venus::Log->new->debug(@args);
+  my $log = Venus::Log->new($ENV{VENUS_LOG_LEVEL});
+
+  return $log if !@args;
+
+  my $code = shift @args;
+
+  return $log->$code(@args);
 }
 
 sub make (@) {
@@ -1123,7 +1158,7 @@ OO Standard Library for Perl 5
 
 =head1 VERSION
 
-3.40
+3.55
 
 =cut
 
@@ -1422,6 +1457,70 @@ I<Since C<2.40>>
 
 =cut
 
+=head2 async
+
+  async(CodeRef $code, Any @args) (Process)
+
+The async function accepts a callback and executes it asynchronously via
+L<Venus::Process/async>. This function returns a
+L<"dyadic"|Venus::Process/is_dyadic> L<Venus::Process> object which can be used
+with L</await>.
+
+I<Since C<3.40>>
+
+=over 4
+
+=item async example 1
+
+  package main;
+
+  use Venus 'async';
+
+  my $async = async sub{
+    'done'
+  };
+
+  # bless({...}, 'Venus::Process')
+
+=back
+
+=cut
+
+=head2 await
+
+  await(Process $process, Int $timeout) (Any)
+
+The await function accepts a L<"dyadic"|Venus::Process/is_dyadic>
+L<Venus::Process> object and eventually returns a value (or values) for it. The
+value(s) returned are the return values or emissions from the asychronous
+callback executed with L</async> which produced the process object.
+
+I<Since C<3.40>>
+
+=over 4
+
+=item await example 1
+
+  package main;
+
+  use Venus 'async', 'await';
+
+  my $process;
+
+  my $async = async sub{
+    ($process) = @_;
+    # in forked process ...
+    return 'done';
+  };
+
+  my $await = await $async;
+
+  # ['done']
+
+=back
+
+=cut
+
 =head2 bool
 
   bool(Any $value) (Boolean)
@@ -3053,7 +3152,10 @@ I<Since C<2.32>>
   log(Any @args) (Log)
 
 The log function prints the arguments provided to STDOUT, stringifying complex
-values, and returns a L<Venus::Log> object.
+values, and returns a L<Venus::Log> object. If the first argument is a log
+level name, e.g. C<debug>, C<error>, C<fatal>, C<info>, C<trace>, or C<warn>,
+it will be used when emitting the event. The desired log level is specified by
+the C<VENUS_LOG_LEVEL> environment variable and defaults to C<trace>.
 
 I<Since C<2.40>>
 
