@@ -1156,8 +1156,12 @@ sub test {
         $type_map{$type}
       );
       if (my $caught = $assert->catch('validate', $values[$i])) {
-        my $error = "error_on_${key}_validation";
-        $self->throw($error, $caught->message, $name, $type)->error;
+        $self->error({
+          throw => "error_on_${key}_validation",
+          error => $caught->message,
+          name => $name,
+          type => $type,
+        });
       }
     }
   }
@@ -1196,29 +1200,45 @@ sub _wrap_text {
 # ERRORS
 
 sub error_on_arg_validation {
-  my ($self, $error, $name, $type) = @_;
+  my ($self, $data) = @_;
 
-  return {
-    name => 'on.arg.validation',
-    message => (join ': ', 'Invalid argument', $name, $error),
-    stash => {
-      name => $name,
-      type => $type,
-    },
+  my $message = 'Invalid argument: {{name}}: {{error}}';
+
+  my $stash = {
+    name => $data->{name},
+    type => $data->{type},
+    error => $data->{error},
   };
+
+  my $result = {
+    name => 'on.arg.validation',
+    raise => true,
+    stash => $stash,
+    message => $message,
+  };
+
+  return $result;
 }
 
 sub error_on_opt_validation {
-  my ($self, $error, $name, $type) = @_;
+  my ($self, $data) = @_;
 
-  return {
-    name => 'on.opt.validation',
-    message => (join ': ', 'Invalid option', $name, $error),
-    stash => {
-      name => $name,
-      type => $type,
-    },
+  my $message = 'Invalid option: {{name}}: {{error}}';
+
+  my $stash = {
+    name => $data->{name},
+    type => $data->{type},
+    error => $data->{error},
   };
+
+  my $result = {
+    name => 'on.opt.validation',
+    raise => true,
+    stash => $stash,
+    message => $message,
+  };
+
+  return $result;
 }
 
 1;
@@ -2712,15 +2732,20 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = ("...", "example", "string");
+  my $input = {
+    throw => 'error_on_arg_validation',
+    error => "...",
+    name => "example",
+    type => "string",
+  };
 
-  my $error = $cli->throw('error_on_arg_validation', @args)->catch('error');
+  my $error = $cli->catch('error', $input);
 
   # my $name = $error->name;
 
   # "on_arg_validation"
 
-  # my $message = $error->message;
+  # my $message = $error->render;
 
   # "Invalid argument: example: ..."
 
@@ -2744,15 +2769,20 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = ("...", "example", "string");
+  my $input = {
+    throw => 'error_on_opt_validation',
+    error => "...",
+    name => "example",
+    type => "string",
+  };
 
-  my $error = $cli->throw('error_on_opt_validation', @args)->catch('error');
+  my $error = $cli->catch('error', $input);
 
   # my $name = $error->name;
 
   # "on_opt_validation"
 
-  # my $message = $error->message;
+  # my $message = $error->render;
 
   # "Invalid option: example: ..."
 
