@@ -5,6 +5,8 @@ use 5.018;
 use strict;
 use warnings;
 
+no warnings 'once';
+
 use base 'Venus::Core';
 
 # METHODS
@@ -28,6 +30,12 @@ sub DESTROY {
 
   no strict 'refs';
 
+  my @mixins = @{$self->META->mixins};
+
+  for my $action (grep defined, map *{"${_}::DESTROY"}{"CODE"}, @mixins) {
+    $self->$action(@data);
+  }
+
   my @roles = @{$self->META->roles};
 
   for my $action (grep defined, map *{"${_}::DESTROY"}{"CODE"}, @roles) {
@@ -62,12 +70,30 @@ sub does {
   return $self->DOES(@args);
 }
 
+sub import {
+  my ($self) = @_;
+
+  require Venus;
+
+  @_ = ("${self} cannot be used via the \"use\" declaration");
+
+  goto \&Venus::fault;
+}
+
 sub meta {
   my ($self) = @_;
 
   return $self->META;
 }
 
+sub unimport {
+  my ($self, @args) = @_;
+
+  my $target = caller;
+
+  return $self->UNIMPORT($target, @args);
+}
+
 1;
 
 
@@ -159,6 +185,30 @@ I<Since C<1.00>>
 
 =cut
 
+=head2 import
+
+  import(Any @args) (Any)
+
+The import method throws a fatal exception whenever the L<perlfunc/use>
+declaration is used with roles as they are meant to be consumed via the C<with>
+or C<role> keyword functions.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item import example 1
+
+  package main;
+
+  use Person;
+
+  # Exception! (isa Venus::Fault)
+
+=back
+
+=cut
+
 =head2 meta
 
   meta() (Meta)
@@ -187,6 +237,29 @@ I<Since C<1.00>>
 
 =cut
 
+=head2 unimport
+
+  unimport(Any @args) (Any)
+
+The unimport method invokes the C<UNIMPORT> lifecycle hook and is invoked
+whenever the L<perlfunc/no> declaration is used.
+
+I<Since C<2.91>>
+
+=over 4
+
+=item unimport example 1
+
+  package main;
+
+  no User;
+
+  # ()
+
+=back
+
+=cut
+
 =head1 AUTHORS
 
 Awncorp, C<awncorp@cpan.org>
