@@ -76,7 +76,7 @@ sub config {
   my ($self, $package) = @_;
 
   $package ||= $self->package
-    or $self->throw('error_on_config')->error;
+    or $self->error({throw => 'error_on_config'});
 
   $package = $package->new
     ->canonical
@@ -238,6 +238,7 @@ sub error_on_config {
   return {
     name => 'on.config',
     message => 'No suitable JSON package',
+    raise => true,
   };
 }
 
@@ -393,7 +394,11 @@ B<example 1>
 
   # given: synopsis;
 
-  my $error = $json->throw('error_on_config')->catch('error');
+  my $input = {
+    throw => 'error_on_config',
+  };
+
+  my $error = $json->catch('error', $input);
 
   # my $name = $error->name;
 
