@@ -61,6 +61,10 @@ sub _forkable {
   $Config::Config{d_pseudofork} ? 0 : 1;
 }
 
+sub _serve {
+  true;
+}
+
 sub _kill {
   CORE::kill(@_);
 }
@@ -107,12 +111,82 @@ sub assertion {
   return $assert;
 }
 
+sub async {
+  my ($self, $code, @args) = @_;
+
+  require Venus::Path;
+
+  my $path = $PATH;
+
+  $PATH = Venus::Path->mktemp_dir->absolute->value;
+
+  my $parent = $self->class->new;
+
+  $parent->{directory} = $PATH;
+
+  $parent->register;
+
+  $parent->work(sub{
+    my ($process) = @_;
+
+    $process->untrap;
+
+    $process->{directory} = $PATH;
+
+    $process->register;
+
+    my $result = $process->try($code, @args)->any->result;
+
+    $process->sendall($result) if defined $result;
+
+    return;
+  });
+
+  $parent->trap(INT => sub {
+    $parent->killall;
+  });
+
+  $parent->trap(TERM => sub {
+    $parent->killall;
+  });
+
+  $PATH = $path;
+
+  return $parent;
+}
+
+sub await {
+  my ($self, $timeout) = @_;
+
+  my $path = $PATH;
+
+  $PATH = $self->{directory};
+
+  my $result;
+
+  if (defined $timeout) {
+    (my $error, $result) = $self->catch('poll', $timeout, 'recvall');
+  }
+  else {
+    do{$result = $self->recvall} while !@{$result};
+  }
+
+  $PATH = $path;
+
+  return wantarray ? ($result ? (@{$result}) : ()) : $result;
+}
+
 sub chdir {
   my ($self, $path) = @_;
 
   $path ||= $CWD;
 
-  _chdir($path) or $self->throw('error_on_chdir', $path, $PID, $!)->error;
+  _chdir($path) or $self->error({
+    throw => 'error_on_chdir',
+    path => $path,
+    pid => $PID,
+    error => $!
+  });
 
   return $self;
 }
@@ -244,7 +318,7 @@ sub fork {
   my ($self, $code, @args) = @_;
 
   if (not(_forkable())) {
-    $self->throw('error_on_fork_support', $PID)->error;
+    $self->error({throw => 'error_on_fork_support', pid => $PID});
   }
   if (defined(my $pid = _fork())) {
     if ($pid) {
@@ -270,7 +344,7 @@ sub fork {
     return wantarray ? ($process, $PID) : $process;
   }
   else {
-    $self->throw('error_on_fork_process', $PID, $!)->error;
+    $self->error({throw => 'error_on_fork_process', error => $!, pid => $PID});
   }
 }
 
@@ -294,6 +368,23 @@ sub forks {
   return wantarray ? ($process ? ($process, []) : ($process, [@pids]) ) : $process;
 }
 
+sub is_dyadic {
+  my ($self) = @_;
+
+  my $directory = $self->{directory};
+
+  my $path = $PATH;
+
+  my $temporary = $PATH = $directory if $directory;
+
+  my $is_dyadic = $directory && ($temporary) && $self->is_registered && ($self->ppid || $self->count == 1)
+    ? true : false;
+
+  $PATH = $path;
+
+  return $is_dyadic;
+}
+
 sub is_leader {
   my ($self) = @_;
 
@@ -365,6 +456,18 @@ sub leave {
   return $self;
 }
 
+sub limit {
+  my ($self, $count) = @_;
+
+  if ($self->count >= $count) {
+    $self->prune while $self->count >= $count;
+    return true;
+  }
+  else {
+    return false;
+  }
+}
+
 sub others {
   my ($self) = @_;
 
@@ -447,7 +550,11 @@ sub poll {
   }
 
   if (!$seen) {
-    $self->throw('error_on_timeout_poll', $timeout, $code)->error;
+    $self->error({
+      throw => 'error_on_timeout_poll',
+      timeout => $timeout,
+      code => $code
+    });
   }
 
   return wantarray ? @{$result} : $result;
@@ -474,7 +581,11 @@ sub pool {
   }
 
   if ($seen < $count) {
-    $self->throw('error_on_timeout_pool', $timeout, $count)->error;
+    $self->error({
+      throw => 'error_on_timeout_pool',
+      timeout => $timeout,
+      pool_size => $count
+    });
   }
 
   @{$self->watchlist} = @pids;
@@ -658,10 +769,19 @@ sub send_key {
   return CORE::join '.', $self->pid, $pid;
 }
 
+sub serve {
+  my ($self, $count, $code) = @_;
+
+  do {$self->work($code) until $self->limit($count)} while _serve;
+
+  return $self;
+}
+
 sub setsid {
   my ($self) = @_;
 
-  return _setsid != -1 || $self->throw('error_on_setid', $PID, $!)->error;
+  return _setsid != -1
+    || $self->error({throw => 'error_on_setid', pid => $PID, error => $!});
 }
 
 sub started {
@@ -702,8 +822,12 @@ sub stderr {
     _open(\*STDERR, '>&', $STDERR);
   }
   else {
-    _open(\*STDERR, '>&', IO::File->new($path, 'w'))
-      or $self->throw('error_on_stderr', $path, $PID, $!)->error;
+    _open(\*STDERR, '>&', IO::File->new($path, 'w')) or $self->error({
+      throw => 'error_on_stderr',
+      path => $path,
+      pid => $PID,
+      error => $!
+    });
   }
 
   return $self;
@@ -721,8 +845,12 @@ sub stdin {
     _open(\*STDIN, '<&', $STDIN);
   }
   else {
-    _open(\*STDIN, '<&', IO::File->new($path, 'r'))
-      or $self->throw('error_on_stdin', $path, $PID, $!)->error;
+    _open(\*STDIN, '<&', IO::File->new($path, 'r')) or $self->error({
+      throw => 'error_on_stdin',
+      path => $path,
+      pid => $PID,
+      error => $!
+    });
   }
 
   return $self;
@@ -740,8 +868,12 @@ sub stdout {
     _open(\*STDOUT, '>&', $STDOUT);
   }
   else {
-    _open(\*STDOUT, '>&', IO::File->new($path, 'w'))
-      or $self->throw('error_on_stdout', $path, $PID, $!)->error;
+    _open(\*STDOUT, '>&', IO::File->new($path, 'w')) or $self->error({
+      throw => 'error_on_stdout',
+      path => $path,
+      pid => $PID,
+      error => $!
+    });
   }
 
   return $self;
@@ -779,7 +911,11 @@ sub sync {
   }
 
   if ($msgs < $count) {
-    $self->throw('error_on_timeout_sync', $timeout, $count)->error;
+    $self->error({
+      throw => 'error_on_timeout_sync',
+      timeout => $timeout,
+      pool_size => $count
+    });
   }
 
   return $self;
@@ -790,7 +926,7 @@ sub trap {
 
   $SIG{uc($name)} = !ref($expr) ? uc($expr) : sub {
     local($!, $?);
-    return $expr->(@_);
+    return $self->$expr->(uc($name), @_);
   };
 
   return $self;
@@ -920,161 +1056,233 @@ sub unwatch {
   return wantarray ? @{$watchlist} : $watchlist;
 }
 
+# DESTROY
+
+sub DESTROY {
+  my ($self, @data) = @_;
+
+  $self->SUPER::DESTROY(@data);
+
+  require Venus::Path;
+
+  Venus::Path->new($self->{directory})->rmdirs if $self->is_dyadic && $self->is_leader;
+
+  return $self;
+}
+
 # ERRORS
 
 sub error_on_chdir {
-  my ($self, $path, $pid, $err) = @_;
+  my ($self, $data) = @_;
 
-  $err = "" if !defined $err;
+  my $message = 'Can\'t chdir "{{path}}": {{error}}';
 
-  return {
-    name => 'on.chdir',
-    message => "Can't chdir \"$path\": $err",
-    stash => {
-      path => $path,
-      pid => $pid,
-    }
+  my $stash = {
+    error => $data->{error},
+    path => $data->{path},
+    pid => $data->{pid},
   };
+
+  my $result = {
+    name => 'on.chdir',
+    raise => true,
+    stash => $stash,
+    message => $message,
+  };
+
+  return $result;
 }
 
 sub error_on_fork_process {
-  my ($self, $pid, $err) = @_;
+  my ($self, $data) = @_;
 
-  $err = "" if !defined $err;
+  my $message = 'Can\'t fork process {{pid}}: {{error}}';
 
-  return {
-    name => 'on.fork.process',
-    message => "Can't fork process $pid: $err",
-    stash => {
-      pid => $pid,
-    }
+  my $stash = {
+    error => $data->{error},
+    pid => $data->{pid},
   };
+
+  my $result = {
+    name => 'on.fork.process',
+    raise => true,
+    stash => $stash,
+    message => $message,
+  };
+
+  return $result;
 }
 
 sub error_on_fork_support {
-  my ($self, $pid) = @_;
+  my ($self, $data) = @_;
 
-  return {
-    name => 'on.fork.support',
-    message => "Can't fork process $pid: Fork emulation not supported",
-    stash => {
-      pid => $pid,
-    }
+  my $message = 'Can\'t fork process {{pid}}: Fork emulation not supported';
+
+  my $stash = {
+    pid => $data->{pid},
   };
+
+  my $result = {
+    name => 'on.fork.support',
+    raise => true,
+    stash => $stash,
+    message => $message,
+  };
+
+  return $result;
 }
 
 sub error_on_setid {
-  my ($self, $pid, $err) = @_;
+  my ($self, $data) = @_;
 
-  $err = "" if !defined $err;
+  my $message = 'Can\'t start a new session: {{error}}';
 
-  return {
-    name => 'on.setid',
-    message => "Can't start a new session: $err",
-    stash => {
-      pid => $pid,
-    }
+  my $stash = {
+    error => $data->{error},
+    pid => $data->{pid},
   };
+
+  my $result = {
+    name => 'on.setid',
+    raise => true,
+    stash => $stash,
+    message => $message,
+  };
+
+  return $result;
 }
 
 sub error_on_stderr {
-  my ($self, $path, $pid, $err) = @_;
+  my ($self, $data) = @_;
 
-  $err = "" if !defined $err;
+  my $message = 'Can\'t redirect STDERR to "{{path}}": {{error}}';
 
-  return {
-    name => 'on.stderr',
-    message => "Can't redirect STDERR to \"$path\": $err",
-    stash => {
-      path => $path,
-      pid => $pid,
-    }
+  my $stash = {
+    error => $data->{error},
+    path => $data->{path},
+    pid => $data->{pid},
   };
+
+  my $result = {
+    name => 'on.stderr',
+    raise => true,
+    stash => $stash,
+    message => $message,
+  };
+
+  return $result;
 }
 
 sub error_on_stdin {
-  my ($self, $path, $pid, $err) = @_;
+  my ($self, $data) = @_;
 
-  $err = "" if !defined $err;
+  my $message = 'Can\'t redirect STDIN to "{{path}}": {{error}}';
 
-  return {
-    name => 'on.stdin',
-    message => "Can't redirect STDIN to \"$path\": $err",
-    stash => {
-      path => $path,
-      pid => $pid,
-    }
+  my $stash = {
+    error => $data->{error},
+    path => $data->{path},
+    pid => $data->{pid},
   };
+
+  my $result = {
+    name => 'on.stdin',
+    raise => true,
+    stash => $stash,
+    message => $message,
+  };
+
+  return $result;
 }
 
 sub error_on_stdout {
-  my ($self, $path, $pid, $err) = @_;
+  my ($self, $data) = @_;
 
-  $err = "" if !defined $err;
+  my $message = 'Can\'t redirect STDOUT to "{{path}}": {{error}}';
 
-  return {
-    name => 'on.stdout',
-    message => "Can't redirect STDOUT to \"$path\": $err",
-    stash => {
-      path => $path,
-      pid => $pid,
-    }
+  my $stash = {
+    error => $data->{error},
+    path => $data->{path},
+    pid => $data->{pid},
   };
+
+  my $result = {
+    name => 'on.stdout',
+    raise => true,
+    stash => $stash,
+    message => $message,
+  };
+
+  return $result;
 }
 
 sub error_on_timeout_poll {
-  my ($self, $timeout, $code) = @_;
+  my ($self, $data) = @_;
 
-  my $name = ref $code eq 'CODE' ? '__ANON__' : "\"$code\"";
-  my $exchange = $self->exchange;
-  my $pid = $self->pid;
+  my $message = CORE::join ' ', 'Timed out after {{timeout}} seconds',
+    'in process {{pid}} while polling {{name}}';
 
-  return {
-    name => 'on.timeout.poll',
-    message => "Timed out after $timeout seconds in process $pid while polling $name",
-    stash => {
-      exchange => $exchange,
-      pid => $pid,
-      code => $code,
-      timeout => $timeout,
-    }
+  my $stash = {
+    code => $data->{code},
+    exchange => $self->exchange,
+    name => (ref $data->{code} eq 'CODE' ? '__ANON__' : $data->{code}),
+    pid => $self->pid,
+    timeout => $data->{timeout},
   };
+
+  my $result = {
+    name => 'on.timeout.poll',
+    raise => true,
+    stash => $stash,
+    message => $message,
+  };
+
+  return $result;
 }
 
 sub error_on_timeout_pool {
-  my ($self, $timeout, $pool_size) = @_;
+  my ($self, $data) = @_;
 
-  my $exchange = $self->exchange;
-  my $pid = $self->pid;
+  my $message = CORE::join ' ', 'Timed out after {{timeout}} seconds',
+    'in process {{pid}} while pooling';
 
-  return {
-    name => 'on.timeout.pool',
-    message => "Timed out after $timeout seconds in process $pid while pooling",
-    stash => {
-      exchange => $exchange,
-      pid => $pid,
-      pool_size => $pool_size,
-      timeout => $timeout,
-    }
+  my $stash = {
+    pool_size => $data->{pool_size},
+    exchange => $self->exchange,
+    pid => $self->pid,
+    timeout => $data->{timeout},
   };
+
+  my $result = {
+    name => 'on.timeout.pool',
+    raise => true,
+    stash => $stash,
+    message => $message,
+  };
+
+  return $result;
 }
 
 sub error_on_timeout_sync {
-  my ($self, $timeout, $pool_size) = @_;
+  my ($self, $data) = @_;
 
-  my $exchange = $self->exchange;
-  my $pid = $self->pid;
+  my $message = CORE::join ' ', 'Timed out after {{timeout}} seconds',
+    'in process {{pid}} while syncing';
 
-  return {
-    name => 'on.timeout.sync',
-    message => "Timed out after $timeout seconds in process $pid while syncing",
-    stash => {
-      exchange => $exchange,
-      pid => $pid,
-      pool_size => $pool_size,
-      timeout => $timeout,
-    }
+  my $stash = {
+    pool_size => $data->{pool_size},
+    exchange => $self->exchange,
+    pid => $self->pid,
+    timeout => $data->{timeout},
   };
+
+  my $result = {
+    name => 'on.timeout.sync',
+    raise => true,
+    stash => $stash,
+    message => $message,
+  };
+
+  return $result;
 }
 
 1;
@@ -1195,6 +1403,161 @@ This package provides the following methods:
 
 =cut
 
+=head2 async
+
+  async(CodeRef $code, Any @args) (Process)
+
+The async method creates a new L<Venus::Process> object and asynchronously runs
+the callback provided via the L</work> method. Both process objects are
+configured to be are dyadic, i.e. representing an exclusing bi-directoral
+relationship. Additionally, the callback return value will be automatically
+made available via the L</await> method unless it's undefined. This method
+returns the newly created L<"dyadic"|/is_dyadic> process object.
+
+I<Since C<3.40>>
+
+=over 4
+
+=item async example 1
+
+  # given: synopsis;
+
+  my $async = $parent->async(sub{
+    my ($process) = @_;
+    # in forked process ...
+    $process->exit;
+  });
+
+  # bless({...}, 'Venus::Process')
+
+=back
+
+=cut
+
+=head2 await
+
+  await(Int $timeout) (Any)
+
+The await method expects to operate on a L<"dyadic"|/is_dyadic> process object
+and blocks the execution of the current process until a value is received from
+its couterpart. If a timeout is provided, execution will be blocked until a
+value is received or the wait time expires. If a timeout of C<0> is provided,
+execution will not be blocked. If no timeout is provided at all, execution will
+block indefinitely.
+
+I<Since C<3.40>>
+
+=over 4
+
+=item await example 1
+
+  # given: synopsis;
+
+  my $async = $parent->async(sub{
+    ($process) = @_;
+    # in forked process ...
+    return 'done';
+  });
+
+  my $await = $async->await;
+
+  # ['done']
+
+=back
+
+=over 4
+
+=item await example 2
+
+  # given: synopsis;
+
+  my $async = $parent->async(sub{
+    ($process) = @_;
+    # in forked process ...
+    return {status => 'done'};
+  });
+
+  my $await = $async->await;
+
+  # [{status => 'done'}]
+
+=back
+
+=over 4
+
+=item await example 3
+
+  # given: synopsis;
+
+  my $async = $parent->async(sub{
+    ($process) = @_;
+    # in forked process ...
+    return 'done';
+  });
+
+  my ($await) = $async->await;
+
+  # 'done'
+
+=back
+
+=over 4
+
+=item await example 4
+
+  # given: synopsis;
+
+  my $async = $parent->async(sub{
+    ($process) = @_;
+    # in forked process ...
+    return {status => 'done'};
+  });
+
+  my ($await) = $async->await;
+
+  # {status => 'done'}
+
+=back
+
+=over 4
+
+=item await example 5
+
+  # given: synopsis;
+
+  my $async = $parent->async(sub{
+    ($process) = @_;
+    # in forked process ...
+    $process->sendall('send 1');
+    $process->sendall('send 2');
+    $process->sendall('send 3');
+    return;
+  });
+
+  my $await;
+
+  my $results = [];
+
+  push @$results, $async->await;
+
+  # 'send 1'
+
+  push @$results, $async->await;
+
+  # 'send 2'
+
+  push @$results, $async->await;
+
+  # 'send 3'
+
+  $results;
+
+  # ['send 1', 'send 2', 'send 3']
+
+=back
+
+=cut
+
 =head2 chdir
 
   chdir(Str $path) (Process)
@@ -2512,6 +2875,63 @@ I<Since C<2.91>>
 
 =cut
 
+=head2 limit
+
+  limit(Int $count) (Bool)
+
+The limit method blocks the execution of the current process until the number
+of processes in the L</watchlist> falls bellow the count specified. The method
+returns true once execution continues if execution was blocked, and false if
+the limit has yet to be reached.
+
+I<Since C<3.40>>
+
+=over 4
+
+=item limit example 1
+
+  package main;
+
+  use Venus::Process;
+
+  my $parent = Venus::Process->new;
+
+  $parent->work(sub {
+    my ($process) = @_;
+    # in forked process ...
+    $process->exit;
+  });
+
+  my $limit = $parent->limit(2);
+
+  # false
+
+=back
+
+=over 4
+
+=item limit example 2
+
+  package main;
+
+  use Venus::Process;
+
+  my $parent = Venus::Process->new;
+
+  $parent->works(2, sub {
+    my ($process) = @_;
+    # in forked process ...
+    $process->exit;
+  });
+
+  my $limit = $parent->limit(2);
+
+  # true
+
+=back
+
+=cut
+
 =head2 others
 
   others() (ArrayRef)
@@ -3447,6 +3867,63 @@ I<Since C<2.91>>
 
 =cut
 
+=head2 serve
+
+  serve(Int $count, CodeRef $callback) (Process)
+
+The serve method executes the callback using L</work> until L</limit> blocks
+the execution of the current process, indefinitely. It has the effect of
+serving the callback and maintaining the desired number of forks until killed
+or gracefully shutdown.
+
+I<Since C<3.40>>
+
+=over 4
+
+=item serve example 1
+
+  package main;
+
+  use Venus::Process;
+
+  my $parent = Venus::Process->new;
+
+  $parent->serve(2, sub {
+    my ($process) = @_;
+    # in forked process ...
+    $process->exit;
+  });
+
+  # ...
+
+  # bless({...}, "Venus::Process")
+
+=back
+
+=over 4
+
+=item serve example 2
+
+  package main;
+
+  use Venus::Process;
+
+  my $parent = Venus::Process->new;
+
+  $parent->serve(10, sub {
+    my ($process) = @_;
+    # in forked process ...
+    $process->exit;
+  });
+
+  # ...
+
+  # bless({...}, "Venus::Process")
+
+=back
+
+=cut
+
 =head2 setsid
 
   setsid() (Int)
@@ -4387,15 +4864,20 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = ('/nowhere', 123);
+  my $input = {
+    throw => 'error_on_chdir',
+    error => $!,
+    path => '/nowhere',
+    pid => 123,
+  };
 
-  my $error = $parent->throw('error_on_chdir', @args)->catch('error');
+  my $error = $parent->catch('error', $input);
 
   # my $name = $error->name;
 
   # "on_chdir"
 
-  # my $message = $error->message;
+  # my $message = $error->render;
 
   # "Can't chdir \"$path\": $!"
 
@@ -4419,15 +4901,19 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = (123);
+  my $input = {
+    throw => 'error_on_fork_process',
+    error => $!,
+    pid => 123,
+  };
 
-  my $error = $parent->throw('error_on_fork_process', @args)->catch('error');
+  my $error = $parent->catch('error', $input);
 
   # my $name = $error->name;
 
   # "on_fork_process"
 
-  # my $message = $error->message;
+  # my $message = $error->render;
 
   # "Can't fork process $pid: $!"
 
@@ -4447,15 +4933,18 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = (123);
+  my $input = {
+    throw => 'error_on_fork_support',
+    pid => 123,
+  };
 
-  my $error = $parent->throw('error_on_fork_support', @args)->catch('error');
+  my $error = $parent->catch('error', $input);
 
   # my $name = $error->name;
 
   # "on_fork_support"
 
-  # my $message = $error->message;
+  # my $message = $error->render;
 
   # "Can't fork process $pid: Fork emulation not supported"
 
@@ -4475,15 +4964,19 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = (123);
+  my $input = {
+    throw => 'error_on_setid',
+    error => $!,
+    pid => 123,
+  };
 
-  my $error = $parent->throw('error_on_setid', @args)->catch('error');
+  my $error = $parent->catch('error', $input);
 
   # my $name = $error->name;
 
   # "on_setid"
 
-  # my $message = $error->message;
+  # my $message = $error->render;
 
   # "Can't start a new session: $!"
 
@@ -4503,15 +4996,20 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = ("/nowhere", 123);
+  my $input = {
+    throw => 'error_on_stderr',
+    error => $!,
+    path => "/nowhere",
+    pid => 123,
+  };
 
-  my $error = $parent->throw('error_on_stderr', @args)->catch('error');
+  my $error = $parent->catch('error', $input);
 
   # my $name = $error->name;
 
   # "on_stderr"
 
-  # my $message = $error->message;
+  # my $message = $error->render;
 
   # "Can't redirect STDERR to \"/nowhere\": $!"
 
@@ -4535,15 +5033,20 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = ('/nowhere', 123);
+  my $input = {
+    throw => 'error_on_stdin',
+    error => $!,
+    path => "/nowhere",
+    pid => 123,
+  };
 
-  my $error = $parent->throw('error_on_stdin', @args)->catch('error');
+  my $error = $parent->catch('error', $input);
 
   # my $name = $error->name;
 
   # "on_stdin"
 
-  # my $message = $error->message;
+  # my $message = $error->render;
 
   # "Can't redirect STDIN to \"$path\": $!"
 
@@ -4567,15 +5070,20 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = ( '/nowhere', 123);
+  my $input = {
+    throw => 'error_on_stdout',
+    error => $!,
+    path => "/nowhere",
+    pid => 123,
+  };
 
-  my $error = $parent->throw('error_on_stdout', @args)->catch('error');
+  my $error = $parent->catch('error', $input);
 
   # my $name = $error->name;
 
   # "on_stdout"
 
-  # my $message = $error->message;
+  # my $message = $error->render;
 
   # "Can't redirect STDOUT to \"$path\": $!"
 
@@ -4599,15 +5107,19 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = (0, sub{});
+  my $input = {
+    throw => 'error_on_timeout_poll',
+    code => sub{},
+    timeout => 0,
+  };
 
-  my $error = $parent->throw('error_on_timeout_poll', @args)->catch('error');
+  my $error = $parent->catch('error', $input);
 
   # my $name = $error->name;
 
   # "on_timeout_poll"
 
-  # my $message = $error->message;
+  # my $message = $error->render;
 
   # "Timed out after 0 seconds in process 12345 while polling __ANON__"
 
@@ -4639,15 +5151,19 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = (0, 2);
+  my $input = {
+    throw => 'error_on_timeout_pool',
+    pool_size => 2,
+    timeout => 0,
+  };
 
-  my $error = $parent->throw('error_on_timeout_pool', @args)->catch('error');
+  my $error = $parent->catch('error', $input);
 
   # my $name = $error->name;
 
   # "on_timeout_pool"
 
-  # my $message = $error->message;
+  # my $message = $error->render;
 
   # "Timed out after 0 seconds in process 12345 while pooling"
 
@@ -4679,15 +5195,19 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = (0, 2);
+  my $input = {
+    throw => 'error_on_timeout_sync',
+    pool_size => 2,
+    timeout => 0,
+  };
 
-  my $error = $parent->throw('error_on_timeout_sync', @args)->catch('error');
+  my $error = $parent->catch('error', $input);
 
   # my $name = $error->name;
 
   # "on_timeout_sync"
 
-  # my $message = $error->message;
+  # my $message = $error->render;
 
   # "Timed out after 0 seconds in process 12345 while syncing"
 
