@@ -92,7 +92,7 @@ sub evaluate {
   my $error = $@;
 
   if ($error) {
-    $self->throw('error_on_evaluate', $error)->error;
+    $self->error({throw => 'error_on_evaluate', error => $error});
   }
 
   return $self->stash(evaluation => [
@@ -208,12 +208,15 @@ sub set {
 # ERRORS
 
 sub error_on_evaluate {
-  my ($self, $error) = @_;
+  my ($self, $data) = @_;
 
-  return {
+  my $result = {
     name => 'on.evaluate',
-    message => $error,
+    raise => true,
+    message => $data->{error},
   };
+
+  return $result;
 }
 
 1;
@@ -685,9 +688,12 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = ('Exception!');
+  my $input = {
+    throw => 'error_on_evaluate',
+    error => 'Exception!',
+  };
 
-  my $error = $replace->throw('error_on_evaluate', @args)->catch('error');
+  my $error = $replace->catch('error', $input);
 
   # my $name = $error->name;
 
