@@ -9,6 +9,18 @@ use Venus::Role 'with';
 
 # METHODS
 
+sub error {
+  my ($self, $data) = @_;
+
+  my @args = $data;
+
+  unshift @args, delete $data->{throw} if $data->{throw};
+
+  @_ = ($self, @args);
+
+  goto $self->can('throw');
+}
+
 sub throw {
   my ($self, $data, @args) = @_;
 
@@ -70,6 +82,10 @@ sub throw {
   if (exists $data->{on}) {
     $throw->on($data->{on});
   }
+  if (exists $data->{raise}) {
+    @_ = ($throw);
+    goto $throw->can('error');
+  }
 
   return $throw;
 }
@@ -77,7 +93,7 @@ sub throw {
 # EXPORTS
 
 sub EXPORT {
-  ['throw']
+  ['error', 'throw']
 }
 
 1;
@@ -125,20 +141,153 @@ This package provides the following methods:
 
 =cut
 
+=head2 error
+
+  error(HashRef $data) (Any)
+
+The error method dispatches to the L</throw> method, excepts a hashref of
+options to be provided to the L</throw> method, and returns the result unless
+an exception is raised automatically. If the C<throw> argument
+is provided it is excepte to be the name of a method used as a callback to
+provide arguments to the thrower.
+
+I<Since C<3.40>>
+
+=over 4
+
+=item error example 1
+
+  package main;
+
+  my $example = Example->new;
+
+  my $throw = $example->error;
+
+  # bless({ "package" => "Example::Error", ..., }, "Venus::Throw")
+
+  # $throw->error;
+
+=back
+
+=over 4
+
+=item error example 2
+
+  package main;
+
+  my $example = Example->new;
+
+  my $throw = $example->error({package => 'Example::Error::Unknown'});
+
+  # bless({ "package" => "Example::Error::Unknown", ..., }, "Venus::Throw")
+
+  # $throw->error;
+
+=back
+
+=over 4
+
+=item error example 3
+
+  package main;
+
+  my $example = Example->new;
+
+  my $throw = $example->error({
+    name => 'on.example',
+    capture => [$example],
+    stash => {
+      time => time,
+    },
+  });
+
+  # bless({ "package" => "Example::Error", ..., }, "Venus::Throw")
+
+  # $throw->error;
+
+=back
+
+=over 4
+
+=item error example 4
+
+  # given: synopsis
+
+  package Example;
+
+  # ...
+
+  sub error_on_example {
+    my ($self) = @_;
+
+    return {
+      name => 'on.example',
+      capture => [$example],
+      stash => {
+        time => time,
+      },
+    };
+  }
+
+  package main;
+
+  my $throw = $example->error({throw => 'error_on_example'});
+
+  # bless({ "package" => "Example::Error", ..., }, "Venus::Throw")
+
+  # $throw->error;
+
+=back
+
+=over 4
+
+=item error example 5
+
+  # given: synopsis
+
+  package Example;
+
+  # ...
+
+  sub error_on_example {
+    my ($self) = @_;
+
+    return {
+      name => 'on.example',
+      capture => [$example],
+      stash => {
+        time => time,
+      },
+      raise => 1,
+    };
+  }
+
+  package main;
+
+  my $throw = $example->error({throw => 'error_on_example'});
+
+  # Exception! (isa Example::Error)
+
+=back
+
+=cut
+
 =head2 throw
 
-  throw(Maybe[Str | HashRef] $data, Any @args) (Throw)
+  throw(Maybe[Str | HashRef] $data, Any @args) (Any)
 
 The throw method builds a L<Venus::Throw> object, which can raise errors
 (exceptions). If passed a string representing a package name, the throw object
 will be configured to throw an exception using that package name. If passed a
 string representing a method name, the throw object will call that method
-expecting a hashref of L<Venus::Throw> method names and arguments which will be
-called to configure the thrower. If passed a hashref, the keys and values are
-expected to be method names and arguments which will be called to configure the
-L<Venus::Throw> object returned. If passed additional arguments, assuming they
-are preceeded by a string representing a method name, the additional arguments
-will be supplied to the method when called.
+expecting a hashref to be returned which will be provided to L<Venus::Throw> as
+arguments to configure the thrower. If passed a hashref, the keys and values
+are expected to be method names and arguments which will be called to configure
+the L<Venus::Throw> object returned. If passed additional arguments, assuming
+they are preceeded by a string representing a method name, the additional
+arguments will be supplied to the method when called. If the C<raise> argument
+is provided (or returned from the callback), the thrower will automatically
+throw the exception.
 
 I<Since C<0.01>>
 
@@ -228,6 +377,37 @@ I<Since C<0.01>>
 
 =back
 
+=over 4
+
+=item throw example 5
+
+  # given: synopsis
+
+  package Example;
+
+  # ...
+
+  sub error_on_example {
+    my ($self) = @_;
+
+    return {
+      name => 'on.example',
+      capture => [$example],
+      stash => {
+        time => time,
+      },
+      raise => 1,
+    };
+  }
+
+  package main;
+
+  my $throw = $example->throw('error_on_example');
+
+  # Exception! (isa Example::Error)
+
+=back
+
 =cut
 
 =head1 AUTHORS
