@@ -247,7 +247,7 @@ sub init {
 
 sub name {
 
-  return $ENV{VENUS_RUN_NAME} || $NAME;
+  return $ENV{VENUS_TASK_NAME} || $NAME;
 }
 
 state $opts = {
@@ -444,7 +444,7 @@ sub _find_in_task {
     ? (
     $conf->{task}{$item}
     ? (do {
-      $ENV{VENUS_TASK_RUN} = 1;
+      $ENV{VENUS_TASK_AUTO} = 1;
       my $value = $conf->{task}{$item};
       ($value eq $item)
         ? ($value)
@@ -483,7 +483,7 @@ sub _find_in_with {
     ? (do {
       $ENV{ECHO} = 0;
       $ENV{VENUS_FILE} = _vars($conf->{with}{$item});
-      $ENV{VENUS_RUN_NAME} || 'vns';
+      $ENV{VENUS_TASK_NAME} || 'vns';
     })
     : ($item)
     )
@@ -1861,7 +1861,7 @@ I<Since C<2.91>>
   name() (Str)
 
 The name method returns the default name for the task. This is used in usage
-text and can be controlled via the C<VENUS_RUN_NAME> environment variable, or
+text and can be controlled via the C<VENUS_TASK_NAME> environment variable, or
 the C<NAME> package variable.
 
 I<Since C<2.91>>
@@ -1888,7 +1888,7 @@ I<Since C<2.91>>
 
   package main;
 
-  local $ENV{VENUS_RUN_NAME} = 'venus-runner';
+  local $ENV{VENUS_TASK_NAME} = 'venus-runner';
 
   my $name = $run->name;
 
@@ -2246,12 +2246,6 @@ L<vns> CLI, which is simply an executable file which loads this package.
   # i.e.
   # cpanm --llocal -qn $DIST
 
-  # Install dependencies in the CWD
-  vns deps
-
-  # i.e.
-  # cpanm --llocal -qn --installdeps .
-
   # Check that a package can be compiled
   vns okay $FILE
 
