@@ -111,6 +111,14 @@ sub default {
   return '';
 }
 
+sub format {
+  my ($self, @args) = @_;
+
+  my $data = $self->get;
+
+  return CORE::sprintf($data, @args);
+}
+
 sub hex {
   my ($self) = @_;
 
@@ -232,7 +240,6 @@ sub render {
 
   while (my($key, $value) = each(%$tokens)) {
     my $token = quotemeta $key;
-
     $data =~ s/\{\{\s*$token\s*\}\}/$value/g;
   }
 
@@ -1020,6 +1027,49 @@ I<Since C<0.08>>
 
 =cut
 
+=head2 format
+
+  format(Any @args) (Str)
+
+The format method performs a L<perlfunc/sprintf> operation using the underlying
+string and arguments provided and returns the result.
+
+I<Since C<3.30>>
+
+=over 4
+
+=item format example 1
+
+  package main;
+
+  use Venus::String;
+
+  my $string = Venus::String->new('hello %s');
+
+  my $format = $string->format('world');
+
+  # "hello world"
+
+=back
+
+=over 4
+
+=item format example 2
+
+  package main;
+
+  use Venus::String;
+
+  my $string = Venus::String->new('id number %08d');
+
+  my $format = $string->format(10);
+
+  # "id number 00000010"
+
+=back
+
+=cut
+
 =head2 ge
 
   ge(Any $arg) (Bool)
