@@ -246,7 +246,7 @@ sub run {
 
   my $CAN_RUN = not(caller(1)) || scalar(caller(1)) eq 'main';
 
-  $self->class->new(@args)->maybe('execute') if $ENV{VENUS_TASK_RUN} && $CAN_RUN;
+  $self->class->new(@args)->maybe('execute') if $ENV{VENUS_TASK_AUTO} && $CAN_RUN;
 
   return $self;
 }
@@ -266,7 +266,11 @@ sub shutdown {
 sub system {
   my ($self, @args) = @_;
 
-  (_system(@args) == 0) or $self->throw('error_on_system_call', \@args, $?)->error;
+  (_system(@args) == 0) or $self->error({
+    throw => 'error_on_system_call',
+    args => [@args],
+    error => $?
+  });
 
   return $self;
 }
@@ -288,17 +292,24 @@ sub usage {
 # ERRORS
 
 sub error_on_system_call {
-  my ($self, $args, $err) = @_;
+  my ($self, $data) = @_;
 
-  $err = "" if !defined $err;
+  my $message = 'Can\'t make system call "{{command}}": {{error}}';
 
-  return {
-    name => 'on.system.call',
-    message => "Can't make system call \"@$args\": $err",
-    stash => {
-      args => $args,
-    }
+  my $stash = {
+    args => $data->{args},
+    command => (join ' ', @{$data->{args}}),
+    error => $data->{error},
   };
+
+  my $result = {
+    name => 'on.system.call',
+    raise => true,
+    stash => $stash,
+    message => $message,
+  };
+
+  return $result;
 }
 
 1;
@@ -1523,7 +1534,7 @@ The run class method will automatically execute the task class by instansiating
 the class and calling the L</execute> method and returns the invocant. This
 method is meant to be used directly in package scope outside of any routine,
 and will only auto-execute under the conditions that the caller is the "main"
-package space and the C<VENUS_TASK_RUN> environment variable is truthy.
+package space and the C<VENUS_TASK_AUTO> environment variable is truthy.
 
 I<Since C<2.91>>
 
@@ -1784,15 +1795,19 @@ B<example 1>
 
   # given: synopsis;
 
-  my @args = (['/path/to/nowhere', 'arg1', 'arg2'], $?);
+  my $input = {
+    throw => 'error_on_system_call',
+    args => ['/path/to/nowhere', 'arg1', 'arg2'],
+    error => $?,
+  };
 
-  my $error = $task->throw('error_on_system_call', @args)->catch('error');
+  my $error = $task->catch('error', $input);
 
   # my $name = $error->name;
 
   # "on_system_call"
 
-  # my $message = $error->message;
+  # my $message = $error->render;
 
   # "Can't make system call \"/path/to/nowhere arg1 arg2\": $?"
 
